pub struct ConversionResult<T> {
pub clipped: bool,
pub value: T,
}Expand description
A conversion result, containing the resulting value as value
and a boolean clipped indicating if the value was clipped during conversion.
Fields
clipped: boolvalue: TAuto Trait Implementations
impl<T> Freeze for ConversionResult<T>where
T: Freeze,
impl<T> RefUnwindSafe for ConversionResult<T>where
T: RefUnwindSafe,
impl<T> Send for ConversionResult<T>where
T: Send,
impl<T> Sync for ConversionResult<T>where
T: Sync,
impl<T> Unpin for ConversionResult<T>where
T: Unpin,
impl<T> UnsafeUnpin for ConversionResult<T>where
T: UnsafeUnpin,
impl<T> UnwindSafe for ConversionResult<T>where
T: UnwindSafe,