pub struct I24_4LJ_BE(/* private fields */);Expand description
24 bit signed integer, big endian. Stored as 4 bytes left justified. The 24 data bits are stored in the three most significant bytes, while the least significant byte is unused padding.