pub struct U24_4RJ_LE(/* private fields */);Expand description
24 bit unsigned integer, little endian. Stored as 4 bytes right justified. The 24 data bits are stored in the three least significant bytes, while the most significant byte is unused padding.